@@ -112,9 +112,7 @@ exit $exit_code"""
     def _install_command(self) -> str:
         repo_name = self.workflow_package.split(".")[0].replace("_", "-")
         version = self.workflow_version
-        artifact_folder = f"{repo_name}_{version}/"
-        # location $CODE_MOUNT is the base path on the worker the code should be installable from
-        return f'pip install $CODE_MOUNT"{artifact_folder}{repo_name}"'
+        return f'pip install {repo_name}=={version}"'
 
     @property
     def _run_command(self) -> str:
